==> calligra-3.0.0.1.tar.xz: calligra-3.0.0.1/stage/part/commands/KPrAnimationEditNodeTypeCommand.h <==
/* This file is part of the KDE project
 * Copyright (C) 2012 Paul Mendez <paulestebanms@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (  at your option ) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KPRANIMATIONEDITNODETYPECOMMAND_H
#define KPRANIMATIONEDITNODETYPECOMMAND_H

#include <kundo2command.h>

#include "animations/KPrShapeAnimation.h"

class KPrShapeAnimations;

/// Command to edit node type
class KPrAnimationEditNodeTypeCommand : public KUndo2Command
{
public:
    KPrAnimationEditNodeTypeCommand(KPrShapeAnimation *animation, KPrShapeAnimation::NodeType oldType,
                                    KPrShapeAnimation::NodeType newType, KPrShapeAnimations *animationModel,
                                    KUndo2Command *parent=0);


    virtual ~KPrAnimationEditNodeTypeCommand();

    /// redo the command
    void redo();
    /// revert the actions done in redo
    void undo();

private:
    KPrShapeAnimation *m_animation;
    KPrShapeAnimation::NodeType m_newType;
    KPrShapeAnimation::NodeType m_oldType;
    KPrShapeAnimations *m_model;
};

#endif // KPRANIMATIONEDITNODETYPECOMMAND_H

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/stage/part/commands/KPrAnimationEditNodeTypeCommand.h <==
/* This file is part of the KDE project
 * Copyright (C) 2012 Paul Mendez <paulestebanms@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (  at your option ) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KPRANIMATIONEDITNODETYPECOMMAND_H
#define KPRANIMATIONEDITNODETYPECOMMAND_H

#include <kundo2command.h>

#include "animations/KPrShapeAnimation.h"

class KPrShapeAnimations;

/// Command to edit node type
class KPrAnimationEditNodeTypeCommand : public KUndo2Command
{
public:
    KPrAnimationEditNodeTypeCommand(KPrShapeAnimation *animation, KPrShapeAnimation::NodeType oldType,
                                    KPrShapeAnimation::NodeType newType, KPrShapeAnimations *animationModel,
                                    KUndo2Command *parent=0);


    ~KPrAnimationEditNodeTypeCommand() override;

    /// redo the command
    void redo() override;
    /// revert the actions done in redo
    void undo() override;

private:
    KPrShapeAnimation *m_animation;
    KPrShapeAnimation::NodeType m_newType;
    KPrShapeAnimation::NodeType m_oldType;
    KPrShapeAnimations *m_model;
};

#endif // KPRANIMATIONEDITNODETYPECOMMAND_H
